# flake8: noqa
"""
Copyright 2020 - Present Okta, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

# AUTO-GENERATED! DO NOT EDIT FILE DIRECTLY
# SEE CONTRIBUTOR DOCUMENTATION

from okta.models import acs_endpoint as acs_endpoint
AcsEndpoint = acs_endpoint.AcsEndpoint
from okta.models import activate_factor_request as activate_factor_request
ActivateFactorRequest = activate_factor_request.ActivateFactorRequest
from okta.models import app_and_instance_condition_evaluator_app_or_instance as app_and_instance_condition_evaluator_app_or_instance
AppAndInstanceConditionEvaluatorAppOrInstance = app_and_instance_condition_evaluator_app_or_instance.AppAndInstanceConditionEvaluatorAppOrInstance
from okta.models import app_and_instance_policy_rule_condition as app_and_instance_policy_rule_condition
AppAndInstancePolicyRuleCondition = app_and_instance_policy_rule_condition.AppAndInstancePolicyRuleCondition
from okta.models import app_instance_policy_rule_condition as app_instance_policy_rule_condition
AppInstancePolicyRuleCondition = app_instance_policy_rule_condition.AppInstancePolicyRuleCondition
from okta.models import app_link as app_link
AppLink = app_link.AppLink
from okta.models import app_user as app_user
AppUser = app_user.AppUser
from okta.models import app_user_credentials as app_user_credentials
AppUserCredentials = app_user_credentials.AppUserCredentials
from okta.models import app_user_password_credential as app_user_password_credential
AppUserPasswordCredential = app_user_password_credential.AppUserPasswordCredential
from okta.models import application as application
Application = application.Application
from okta.models import application_accessibility as application_accessibility
ApplicationAccessibility = application_accessibility.ApplicationAccessibility
from okta.models import application_credentials as application_credentials
ApplicationCredentials = application_credentials.ApplicationCredentials
from okta.models import application_credentials_o_auth_client as application_credentials_o_auth_client
ApplicationCredentialsOAuthClient = application_credentials_o_auth_client.ApplicationCredentialsOAuthClient
from okta.models import application_credentials_scheme as application_credentials_scheme
ApplicationCredentialsScheme = application_credentials_scheme.ApplicationCredentialsScheme
from okta.models import application_credentials_signing as application_credentials_signing
ApplicationCredentialsSigning = application_credentials_signing.ApplicationCredentialsSigning
from okta.models import application_credentials_signing_use as application_credentials_signing_use
ApplicationCredentialsSigningUse = application_credentials_signing_use.ApplicationCredentialsSigningUse
from okta.models import application_credentials_username_template as application_credentials_username_template
ApplicationCredentialsUsernameTemplate = application_credentials_username_template.ApplicationCredentialsUsernameTemplate
from okta.models import application_group_assignment as application_group_assignment
ApplicationGroupAssignment = application_group_assignment.ApplicationGroupAssignment
from okta.models import application_licensing as application_licensing
ApplicationLicensing = application_licensing.ApplicationLicensing
from okta.models import application_settings as application_settings
ApplicationSettings = application_settings.ApplicationSettings
from okta.models import application_settings_application as application_settings_application
ApplicationSettingsApplication = application_settings_application.ApplicationSettingsApplication
from okta.models import application_settings_notifications as application_settings_notifications
ApplicationSettingsNotifications = application_settings_notifications.ApplicationSettingsNotifications
from okta.models import application_settings_notifications_vpn as application_settings_notifications_vpn
ApplicationSettingsNotificationsVpn = application_settings_notifications_vpn.ApplicationSettingsNotificationsVpn
from okta.models import application_settings_notifications_vpn_network as application_settings_notifications_vpn_network
ApplicationSettingsNotificationsVpnNetwork = application_settings_notifications_vpn_network.ApplicationSettingsNotificationsVpnNetwork
from okta.models import application_sign_on_mode as application_sign_on_mode
ApplicationSignOnMode = application_sign_on_mode.ApplicationSignOnMode
from okta.models import application_visibility as application_visibility
ApplicationVisibility = application_visibility.ApplicationVisibility
from okta.models import application_visibility_hide as application_visibility_hide
ApplicationVisibilityHide = application_visibility_hide.ApplicationVisibilityHide
from okta.models import assign_role_request as assign_role_request
AssignRoleRequest = assign_role_request.AssignRoleRequest
from okta.models import authentication_provider as authentication_provider
AuthenticationProvider = authentication_provider.AuthenticationProvider
from okta.models import authentication_provider_type as authentication_provider_type
AuthenticationProviderType = authentication_provider_type.AuthenticationProviderType
from okta.models import authorization_server as authorization_server
AuthorizationServer = authorization_server.AuthorizationServer
from okta.models import authorization_server_credentials as authorization_server_credentials
AuthorizationServerCredentials = authorization_server_credentials.AuthorizationServerCredentials
from okta.models import authorization_server_credentials_rotation_mode as authorization_server_credentials_rotation_mode
AuthorizationServerCredentialsRotationMode = authorization_server_credentials_rotation_mode.AuthorizationServerCredentialsRotationMode
from okta.models import authorization_server_credentials_signing_config as authorization_server_credentials_signing_config
AuthorizationServerCredentialsSigningConfig = authorization_server_credentials_signing_config.AuthorizationServerCredentialsSigningConfig
from okta.models import authorization_server_credentials_use as authorization_server_credentials_use
AuthorizationServerCredentialsUse = authorization_server_credentials_use.AuthorizationServerCredentialsUse
from okta.models import auto_login_application as auto_login_application
AutoLoginApplication = auto_login_application.AutoLoginApplication
from okta.models import auto_login_application_settings as auto_login_application_settings
AutoLoginApplicationSettings = auto_login_application_settings.AutoLoginApplicationSettings
from okta.models import auto_login_application_settings_sign_on as auto_login_application_settings_sign_on
AutoLoginApplicationSettingsSignOn = auto_login_application_settings_sign_on.AutoLoginApplicationSettingsSignOn
from okta.models import basic_application_settings as basic_application_settings
BasicApplicationSettings = basic_application_settings.BasicApplicationSettings
from okta.models import basic_application_settings_application as basic_application_settings_application
BasicApplicationSettingsApplication = basic_application_settings_application.BasicApplicationSettingsApplication
from okta.models import basic_auth_application as basic_auth_application
BasicAuthApplication = basic_auth_application.BasicAuthApplication
from okta.models import before_scheduled_action_policy_rule_condition as before_scheduled_action_policy_rule_condition
BeforeScheduledActionPolicyRuleCondition = before_scheduled_action_policy_rule_condition.BeforeScheduledActionPolicyRuleCondition
from okta.models import bookmark_application as bookmark_application
BookmarkApplication = bookmark_application.BookmarkApplication
from okta.models import bookmark_application_settings as bookmark_application_settings
BookmarkApplicationSettings = bookmark_application_settings.BookmarkApplicationSettings
from okta.models import bookmark_application_settings_application as bookmark_application_settings_application
BookmarkApplicationSettingsApplication = bookmark_application_settings_application.BookmarkApplicationSettingsApplication
from okta.models import browser_plugin_application as browser_plugin_application
BrowserPluginApplication = browser_plugin_application.BrowserPluginApplication
from okta.models import call_user_factor as call_user_factor
CallUserFactor = call_user_factor.CallUserFactor
from okta.models import call_user_factor_profile as call_user_factor_profile
CallUserFactorProfile = call_user_factor_profile.CallUserFactorProfile
from okta.models import catalog_application as catalog_application
CatalogApplication = catalog_application.CatalogApplication
from okta.models import catalog_application_status as catalog_application_status
CatalogApplicationStatus = catalog_application_status.CatalogApplicationStatus
from okta.models import change_password_request as change_password_request
ChangePasswordRequest = change_password_request.ChangePasswordRequest
from okta.models import client_policy_condition as client_policy_condition
ClientPolicyCondition = client_policy_condition.ClientPolicyCondition
from okta.models import context_policy_rule_condition as context_policy_rule_condition
ContextPolicyRuleCondition = context_policy_rule_condition.ContextPolicyRuleCondition
from okta.models import create_session_request as create_session_request
CreateSessionRequest = create_session_request.CreateSessionRequest
from okta.models import create_user_request as create_user_request
CreateUserRequest = create_user_request.CreateUserRequest
from okta.models import csr as csr
Csr = csr.Csr
from okta.models import csr_metadata as csr_metadata
CsrMetadata = csr_metadata.CsrMetadata
from okta.models import csr_metadata_subject as csr_metadata_subject
CsrMetadataSubject = csr_metadata_subject.CsrMetadataSubject
from okta.models import csr_metadata_subject_alt_names as csr_metadata_subject_alt_names
CsrMetadataSubjectAltNames = csr_metadata_subject_alt_names.CsrMetadataSubjectAltNames
from okta.models import custom_hotp_user_factor as custom_hotp_user_factor
CustomHotpUserFactor = custom_hotp_user_factor.CustomHotpUserFactor
from okta.models import custom_hotp_user_factor_profile as custom_hotp_user_factor_profile
CustomHotpUserFactorProfile = custom_hotp_user_factor_profile.CustomHotpUserFactorProfile
from okta.models import device_policy_rule_condition as device_policy_rule_condition
DevicePolicyRuleCondition = device_policy_rule_condition.DevicePolicyRuleCondition
from okta.models import device_policy_rule_condition_platform as device_policy_rule_condition_platform
DevicePolicyRuleConditionPlatform = device_policy_rule_condition_platform.DevicePolicyRuleConditionPlatform
from okta.models import duration as duration
Duration = duration.Duration
from okta.models import email_user_factor as email_user_factor
EmailUserFactor = email_user_factor.EmailUserFactor
from okta.models import email_user_factor_profile as email_user_factor_profile
EmailUserFactorProfile = email_user_factor_profile.EmailUserFactorProfile
from okta.models import enabled_status as enabled_status
EnabledStatus = enabled_status.EnabledStatus
from okta.models import event_hook as event_hook
EventHook = event_hook.EventHook
from okta.models import event_hook_channel as event_hook_channel
EventHookChannel = event_hook_channel.EventHookChannel
from okta.models import event_hook_channel_config as event_hook_channel_config
EventHookChannelConfig = event_hook_channel_config.EventHookChannelConfig
from okta.models import event_hook_channel_config_auth_scheme as event_hook_channel_config_auth_scheme
EventHookChannelConfigAuthScheme = event_hook_channel_config_auth_scheme.EventHookChannelConfigAuthScheme
from okta.models import event_hook_channel_config_auth_scheme_type as event_hook_channel_config_auth_scheme_type
EventHookChannelConfigAuthSchemeType = event_hook_channel_config_auth_scheme_type.EventHookChannelConfigAuthSchemeType
from okta.models import event_hook_channel_config_header as event_hook_channel_config_header
EventHookChannelConfigHeader = event_hook_channel_config_header.EventHookChannelConfigHeader
from okta.models import event_subscriptions as event_subscriptions
EventSubscriptions = event_subscriptions.EventSubscriptions
from okta.models import factor_provider as factor_provider
FactorProvider = factor_provider.FactorProvider
from okta.models import factor_result_type as factor_result_type
FactorResultType = factor_result_type.FactorResultType
from okta.models import factor_status as factor_status
FactorStatus = factor_status.FactorStatus
from okta.models import factor_type as factor_type
FactorType = factor_type.FactorType
from okta.models import feature as feature
Feature = feature.Feature
from okta.models import feature_stage as feature_stage
FeatureStage = feature_stage.FeatureStage
from okta.models import feature_stage_state as feature_stage_state
FeatureStageState = feature_stage_state.FeatureStageState
from okta.models import feature_stage_value as feature_stage_value
FeatureStageValue = feature_stage_value.FeatureStageValue
from okta.models import feature_type as feature_type
FeatureType = feature_type.FeatureType
from okta.models import forgot_password_response as forgot_password_response
ForgotPasswordResponse = forgot_password_response.ForgotPasswordResponse
from okta.models import grant_type_policy_rule_condition as grant_type_policy_rule_condition
GrantTypePolicyRuleCondition = grant_type_policy_rule_condition.GrantTypePolicyRuleCondition
from okta.models import group as group
Group = group.Group
from okta.models import group_condition as group_condition
GroupCondition = group_condition.GroupCondition
from okta.models import group_policy_rule_condition as group_policy_rule_condition
GroupPolicyRuleCondition = group_policy_rule_condition.GroupPolicyRuleCondition
from okta.models import group_profile as group_profile
GroupProfile = group_profile.GroupProfile
from okta.models import group_rule as group_rule
GroupRule = group_rule.GroupRule
from okta.models import group_rule_action as group_rule_action
GroupRuleAction = group_rule_action.GroupRuleAction
from okta.models import group_rule_conditions as group_rule_conditions
GroupRuleConditions = group_rule_conditions.GroupRuleConditions
from okta.models import group_rule_expression as group_rule_expression
GroupRuleExpression = group_rule_expression.GroupRuleExpression
from okta.models import group_rule_group_assignment as group_rule_group_assignment
GroupRuleGroupAssignment = group_rule_group_assignment.GroupRuleGroupAssignment
from okta.models import group_rule_group_condition as group_rule_group_condition
GroupRuleGroupCondition = group_rule_group_condition.GroupRuleGroupCondition
from okta.models import group_rule_people_condition as group_rule_people_condition
GroupRulePeopleCondition = group_rule_people_condition.GroupRulePeopleCondition
from okta.models import group_rule_status as group_rule_status
GroupRuleStatus = group_rule_status.GroupRuleStatus
from okta.models import group_rule_user_condition as group_rule_user_condition
GroupRuleUserCondition = group_rule_user_condition.GroupRuleUserCondition
from okta.models import group_type as group_type
GroupType = group_type.GroupType
from okta.models import hardware_user_factor as hardware_user_factor
HardwareUserFactor = hardware_user_factor.HardwareUserFactor
from okta.models import hardware_user_factor_profile as hardware_user_factor_profile
HardwareUserFactorProfile = hardware_user_factor_profile.HardwareUserFactorProfile
from okta.models import identity_provider as identity_provider
IdentityProvider = identity_provider.IdentityProvider
from okta.models import identity_provider_application_user as identity_provider_application_user
IdentityProviderApplicationUser = identity_provider_application_user.IdentityProviderApplicationUser
from okta.models import identity_provider_credentials as identity_provider_credentials
IdentityProviderCredentials = identity_provider_credentials.IdentityProviderCredentials
from okta.models import identity_provider_credentials_client as identity_provider_credentials_client
IdentityProviderCredentialsClient = identity_provider_credentials_client.IdentityProviderCredentialsClient
from okta.models import identity_provider_credentials_signing as identity_provider_credentials_signing
IdentityProviderCredentialsSigning = identity_provider_credentials_signing.IdentityProviderCredentialsSigning
from okta.models import identity_provider_credentials_trust as identity_provider_credentials_trust
IdentityProviderCredentialsTrust = identity_provider_credentials_trust.IdentityProviderCredentialsTrust
from okta.models import identity_provider_policy as identity_provider_policy
IdentityProviderPolicy = identity_provider_policy.IdentityProviderPolicy
from okta.models import identity_provider_policy_rule_condition as identity_provider_policy_rule_condition
IdentityProviderPolicyRuleCondition = identity_provider_policy_rule_condition.IdentityProviderPolicyRuleCondition
from okta.models import inactivity_policy_rule_condition as inactivity_policy_rule_condition
InactivityPolicyRuleCondition = inactivity_policy_rule_condition.InactivityPolicyRuleCondition
from okta.models import inline_hook as inline_hook
InlineHook = inline_hook.InlineHook
from okta.models import inline_hook_channel as inline_hook_channel
InlineHookChannel = inline_hook_channel.InlineHookChannel
from okta.models import inline_hook_channel_config as inline_hook_channel_config
InlineHookChannelConfig = inline_hook_channel_config.InlineHookChannelConfig
from okta.models import inline_hook_channel_config_auth_scheme as inline_hook_channel_config_auth_scheme
InlineHookChannelConfigAuthScheme = inline_hook_channel_config_auth_scheme.InlineHookChannelConfigAuthScheme
from okta.models import inline_hook_channel_config_headers as inline_hook_channel_config_headers
InlineHookChannelConfigHeaders = inline_hook_channel_config_headers.InlineHookChannelConfigHeaders
from okta.models import inline_hook_payload as inline_hook_payload
InlineHookPayload = inline_hook_payload.InlineHookPayload
from okta.models import inline_hook_response as inline_hook_response
InlineHookResponse = inline_hook_response.InlineHookResponse
from okta.models import inline_hook_response_command_value as inline_hook_response_command_value
InlineHookResponseCommandValue = inline_hook_response_command_value.InlineHookResponseCommandValue
from okta.models import inline_hook_response_commands as inline_hook_response_commands
InlineHookResponseCommands = inline_hook_response_commands.InlineHookResponseCommands
from okta.models import inline_hook_status as inline_hook_status
InlineHookStatus = inline_hook_status.InlineHookStatus
from okta.models import inline_hook_type as inline_hook_type
InlineHookType = inline_hook_type.InlineHookType
from okta.models import ion_field as ion_field
IonField = ion_field.IonField
from okta.models import ion_form as ion_form
IonForm = ion_form.IonForm
from okta.models import json_web_key as json_web_key
JsonWebKey = json_web_key.JsonWebKey
from okta.models import jwk_use as jwk_use
JwkUse = jwk_use.JwkUse
from okta.models import lifecycle_expiration_policy_rule_condition as lifecycle_expiration_policy_rule_condition
LifecycleExpirationPolicyRuleCondition = lifecycle_expiration_policy_rule_condition.LifecycleExpirationPolicyRuleCondition
from okta.models import linked_object as linked_object
LinkedObject = linked_object.LinkedObject
from okta.models import linked_object_details as linked_object_details
LinkedObjectDetails = linked_object_details.LinkedObjectDetails
from okta.models import linked_object_details_type as linked_object_details_type
LinkedObjectDetailsType = linked_object_details_type.LinkedObjectDetailsType
from okta.models import log_actor as log_actor
LogActor = log_actor.LogActor
from okta.models import log_authentication_context as log_authentication_context
LogAuthenticationContext = log_authentication_context.LogAuthenticationContext
from okta.models import log_authentication_provider as log_authentication_provider
LogAuthenticationProvider = log_authentication_provider.LogAuthenticationProvider
from okta.models import log_client as log_client
LogClient = log_client.LogClient
from okta.models import log_credential_provider as log_credential_provider
LogCredentialProvider = log_credential_provider.LogCredentialProvider
from okta.models import log_credential_type as log_credential_type
LogCredentialType = log_credential_type.LogCredentialType
from okta.models import log_debug_context as log_debug_context
LogDebugContext = log_debug_context.LogDebugContext
from okta.models import log_event as log_event
LogEvent = log_event.LogEvent
from okta.models import log_geographical_context as log_geographical_context
LogGeographicalContext = log_geographical_context.LogGeographicalContext
from okta.models import log_geolocation as log_geolocation
LogGeolocation = log_geolocation.LogGeolocation
from okta.models import log_ip_address as log_ip_address
LogIpAddress = log_ip_address.LogIpAddress
from okta.models import log_issuer as log_issuer
LogIssuer = log_issuer.LogIssuer
from okta.models import log_outcome as log_outcome
LogOutcome = log_outcome.LogOutcome
from okta.models import log_request as log_request
LogRequest = log_request.LogRequest
from okta.models import log_security_context as log_security_context
LogSecurityContext = log_security_context.LogSecurityContext
from okta.models import log_severity as log_severity
LogSeverity = log_severity.LogSeverity
from okta.models import log_target as log_target
LogTarget = log_target.LogTarget
from okta.models import log_transaction as log_transaction
LogTransaction = log_transaction.LogTransaction
from okta.models import log_user_agent as log_user_agent
LogUserAgent = log_user_agent.LogUserAgent
from okta.models import mdm_enrollment_policy_rule_condition as mdm_enrollment_policy_rule_condition
MdmEnrollmentPolicyRuleCondition = mdm_enrollment_policy_rule_condition.MdmEnrollmentPolicyRuleCondition
from okta.models import o_auth_2_actor as o_auth_2_actor
OAuth2Actor = o_auth_2_actor.OAuth2Actor
from okta.models import o_auth_2_claim as o_auth_2_claim
OAuth2Claim = o_auth_2_claim.OAuth2Claim
from okta.models import o_auth_2_claim_conditions as o_auth_2_claim_conditions
OAuth2ClaimConditions = o_auth_2_claim_conditions.OAuth2ClaimConditions
from okta.models import o_auth_2_client as o_auth_2_client
OAuth2Client = o_auth_2_client.OAuth2Client
from okta.models import o_auth_2_refresh_token as o_auth_2_refresh_token
OAuth2RefreshToken = o_auth_2_refresh_token.OAuth2RefreshToken
from okta.models import o_auth_2_scope as o_auth_2_scope
OAuth2Scope = o_auth_2_scope.OAuth2Scope
from okta.models import o_auth_2_scope_consent_grant as o_auth_2_scope_consent_grant
OAuth2ScopeConsentGrant = o_auth_2_scope_consent_grant.OAuth2ScopeConsentGrant
from okta.models import o_auth_2_scope_consent_grant_source as o_auth_2_scope_consent_grant_source
OAuth2ScopeConsentGrantSource = o_auth_2_scope_consent_grant_source.OAuth2ScopeConsentGrantSource
from okta.models import o_auth_2_scope_consent_grant_status as o_auth_2_scope_consent_grant_status
OAuth2ScopeConsentGrantStatus = o_auth_2_scope_consent_grant_status.OAuth2ScopeConsentGrantStatus
from okta.models import o_auth_2_scopes_mediation_policy_rule_condition as o_auth_2_scopes_mediation_policy_rule_condition
OAuth2ScopesMediationPolicyRuleCondition = o_auth_2_scopes_mediation_policy_rule_condition.OAuth2ScopesMediationPolicyRuleCondition
from okta.models import o_auth_2_token as o_auth_2_token
OAuth2Token = o_auth_2_token.OAuth2Token
from okta.models import o_auth_application_credentials as o_auth_application_credentials
OAuthApplicationCredentials = o_auth_application_credentials.OAuthApplicationCredentials
from okta.models import o_auth_authorization_policy as o_auth_authorization_policy
OAuthAuthorizationPolicy = o_auth_authorization_policy.OAuthAuthorizationPolicy
from okta.models import o_auth_endpoint_authentication_method as o_auth_endpoint_authentication_method
OAuthEndpointAuthenticationMethod = o_auth_endpoint_authentication_method.OAuthEndpointAuthenticationMethod
from okta.models import o_auth_grant_type as o_auth_grant_type
OAuthGrantType = o_auth_grant_type.OAuthGrantType
from okta.models import o_auth_response_type as o_auth_response_type
OAuthResponseType = o_auth_response_type.OAuthResponseType
from okta.models import okta_sign_on_policy as okta_sign_on_policy
OktaSignOnPolicy = okta_sign_on_policy.OktaSignOnPolicy
from okta.models import okta_sign_on_policy_conditions as okta_sign_on_policy_conditions
OktaSignOnPolicyConditions = okta_sign_on_policy_conditions.OktaSignOnPolicyConditions
from okta.models import okta_sign_on_policy_rule as okta_sign_on_policy_rule
OktaSignOnPolicyRule = okta_sign_on_policy_rule.OktaSignOnPolicyRule
from okta.models import okta_sign_on_policy_rule_actions as okta_sign_on_policy_rule_actions
OktaSignOnPolicyRuleActions = okta_sign_on_policy_rule_actions.OktaSignOnPolicyRuleActions
from okta.models import okta_sign_on_policy_rule_conditions as okta_sign_on_policy_rule_conditions
OktaSignOnPolicyRuleConditions = okta_sign_on_policy_rule_conditions.OktaSignOnPolicyRuleConditions
from okta.models import okta_sign_on_policy_rule_signon_actions as okta_sign_on_policy_rule_signon_actions
OktaSignOnPolicyRuleSignonActions = okta_sign_on_policy_rule_signon_actions.OktaSignOnPolicyRuleSignonActions
from okta.models import okta_sign_on_policy_rule_signon_session_actions as okta_sign_on_policy_rule_signon_session_actions
OktaSignOnPolicyRuleSignonSessionActions = okta_sign_on_policy_rule_signon_session_actions.OktaSignOnPolicyRuleSignonSessionActions
from okta.models import open_id_connect_application as open_id_connect_application
OpenIdConnectApplication = open_id_connect_application.OpenIdConnectApplication
from okta.models import open_id_connect_application_consent_method as open_id_connect_application_consent_method
OpenIdConnectApplicationConsentMethod = open_id_connect_application_consent_method.OpenIdConnectApplicationConsentMethod
from okta.models import open_id_connect_application_issuer_mode as open_id_connect_application_issuer_mode
OpenIdConnectApplicationIssuerMode = open_id_connect_application_issuer_mode.OpenIdConnectApplicationIssuerMode
from okta.models import open_id_connect_application_settings as open_id_connect_application_settings
OpenIdConnectApplicationSettings = open_id_connect_application_settings.OpenIdConnectApplicationSettings
from okta.models import open_id_connect_application_settings_client as open_id_connect_application_settings_client
OpenIdConnectApplicationSettingsClient = open_id_connect_application_settings_client.OpenIdConnectApplicationSettingsClient
from okta.models import open_id_connect_application_settings_client_keys as open_id_connect_application_settings_client_keys
OpenIdConnectApplicationSettingsClientKeys = open_id_connect_application_settings_client_keys.OpenIdConnectApplicationSettingsClientKeys
from okta.models import open_id_connect_application_settings_refresh_token as open_id_connect_application_settings_refresh_token
OpenIdConnectApplicationSettingsRefreshToken = open_id_connect_application_settings_refresh_token.OpenIdConnectApplicationSettingsRefreshToken
from okta.models import open_id_connect_application_type as open_id_connect_application_type
OpenIdConnectApplicationType = open_id_connect_application_type.OpenIdConnectApplicationType
from okta.models import open_id_connect_refresh_token_rotation_type as open_id_connect_refresh_token_rotation_type
OpenIdConnectRefreshTokenRotationType = open_id_connect_refresh_token_rotation_type.OpenIdConnectRefreshTokenRotationType
from okta.models import password_credential as password_credential
PasswordCredential = password_credential.PasswordCredential
from okta.models import password_credential_hash as password_credential_hash
PasswordCredentialHash = password_credential_hash.PasswordCredentialHash
from okta.models import password_credential_hash_algorithm as password_credential_hash_algorithm
PasswordCredentialHashAlgorithm = password_credential_hash_algorithm.PasswordCredentialHashAlgorithm
from okta.models import password_credential_hook as password_credential_hook
PasswordCredentialHook = password_credential_hook.PasswordCredentialHook
from okta.models import password_dictionary as password_dictionary
PasswordDictionary = password_dictionary.PasswordDictionary
from okta.models import password_dictionary_common as password_dictionary_common
PasswordDictionaryCommon = password_dictionary_common.PasswordDictionaryCommon
from okta.models import password_expiration_policy_rule_condition as password_expiration_policy_rule_condition
PasswordExpirationPolicyRuleCondition = password_expiration_policy_rule_condition.PasswordExpirationPolicyRuleCondition
from okta.models import password_policy as password_policy
PasswordPolicy = password_policy.PasswordPolicy
from okta.models import password_policy_authentication_provider_condition as password_policy_authentication_provider_condition
PasswordPolicyAuthenticationProviderCondition = password_policy_authentication_provider_condition.PasswordPolicyAuthenticationProviderCondition
from okta.models import password_policy_conditions as password_policy_conditions
PasswordPolicyConditions = password_policy_conditions.PasswordPolicyConditions
from okta.models import password_policy_delegation_settings as password_policy_delegation_settings
PasswordPolicyDelegationSettings = password_policy_delegation_settings.PasswordPolicyDelegationSettings
from okta.models import password_policy_delegation_settings_options as password_policy_delegation_settings_options
PasswordPolicyDelegationSettingsOptions = password_policy_delegation_settings_options.PasswordPolicyDelegationSettingsOptions
from okta.models import password_policy_password_settings as password_policy_password_settings
PasswordPolicyPasswordSettings = password_policy_password_settings.PasswordPolicyPasswordSettings
from okta.models import password_policy_password_settings_age as password_policy_password_settings_age
PasswordPolicyPasswordSettingsAge = password_policy_password_settings_age.PasswordPolicyPasswordSettingsAge
from okta.models import password_policy_password_settings_complexity as password_policy_password_settings_complexity
PasswordPolicyPasswordSettingsComplexity = password_policy_password_settings_complexity.PasswordPolicyPasswordSettingsComplexity
from okta.models import password_policy_password_settings_lockout as password_policy_password_settings_lockout
PasswordPolicyPasswordSettingsLockout = password_policy_password_settings_lockout.PasswordPolicyPasswordSettingsLockout
from okta.models import password_policy_recovery_email as password_policy_recovery_email
PasswordPolicyRecoveryEmail = password_policy_recovery_email.PasswordPolicyRecoveryEmail
from okta.models import password_policy_recovery_email_properties as password_policy_recovery_email_properties
PasswordPolicyRecoveryEmailProperties = password_policy_recovery_email_properties.PasswordPolicyRecoveryEmailProperties
from okta.models import password_policy_recovery_email_recovery_token as password_policy_recovery_email_recovery_token
PasswordPolicyRecoveryEmailRecoveryToken = password_policy_recovery_email_recovery_token.PasswordPolicyRecoveryEmailRecoveryToken
from okta.models import password_policy_recovery_factor_settings as password_policy_recovery_factor_settings
PasswordPolicyRecoveryFactorSettings = password_policy_recovery_factor_settings.PasswordPolicyRecoveryFactorSettings
from okta.models import password_policy_recovery_factors as password_policy_recovery_factors
PasswordPolicyRecoveryFactors = password_policy_recovery_factors.PasswordPolicyRecoveryFactors
from okta.models import password_policy_recovery_question as password_policy_recovery_question
PasswordPolicyRecoveryQuestion = password_policy_recovery_question.PasswordPolicyRecoveryQuestion
from okta.models import password_policy_recovery_question_complexity as password_policy_recovery_question_complexity
PasswordPolicyRecoveryQuestionComplexity = password_policy_recovery_question_complexity.PasswordPolicyRecoveryQuestionComplexity
from okta.models import password_policy_recovery_question_properties as password_policy_recovery_question_properties
PasswordPolicyRecoveryQuestionProperties = password_policy_recovery_question_properties.PasswordPolicyRecoveryQuestionProperties
from okta.models import password_policy_recovery_settings as password_policy_recovery_settings
PasswordPolicyRecoverySettings = password_policy_recovery_settings.PasswordPolicyRecoverySettings
from okta.models import password_policy_rule as password_policy_rule
PasswordPolicyRule = password_policy_rule.PasswordPolicyRule
from okta.models import password_policy_rule_action as password_policy_rule_action
PasswordPolicyRuleAction = password_policy_rule_action.PasswordPolicyRuleAction
from okta.models import password_policy_rule_actions as password_policy_rule_actions
PasswordPolicyRuleActions = password_policy_rule_actions.PasswordPolicyRuleActions
from okta.models import password_policy_rule_conditions as password_policy_rule_conditions
PasswordPolicyRuleConditions = password_policy_rule_conditions.PasswordPolicyRuleConditions
from okta.models import password_policy_settings as password_policy_settings
PasswordPolicySettings = password_policy_settings.PasswordPolicySettings
from okta.models import platform_condition_evaluator_platform as platform_condition_evaluator_platform
PlatformConditionEvaluatorPlatform = platform_condition_evaluator_platform.PlatformConditionEvaluatorPlatform
from okta.models import platform_condition_evaluator_platform_operating_system as platform_condition_evaluator_platform_operating_system
PlatformConditionEvaluatorPlatformOperatingSystem = platform_condition_evaluator_platform_operating_system.PlatformConditionEvaluatorPlatformOperatingSystem
from okta.models import platform_condition_evaluator_platform_operating_system_version as platform_condition_evaluator_platform_operating_system_version
PlatformConditionEvaluatorPlatformOperatingSystemVersion = platform_condition_evaluator_platform_operating_system_version.PlatformConditionEvaluatorPlatformOperatingSystemVersion
from okta.models import platform_policy_rule_condition as platform_policy_rule_condition
PlatformPolicyRuleCondition = platform_policy_rule_condition.PlatformPolicyRuleCondition
from okta.models import policy as policy
Policy = policy.Policy
from okta.models import policy_account_link as policy_account_link
PolicyAccountLink = policy_account_link.PolicyAccountLink
from okta.models import policy_account_link_filter as policy_account_link_filter
PolicyAccountLinkFilter = policy_account_link_filter.PolicyAccountLinkFilter
from okta.models import policy_account_link_filter_groups as policy_account_link_filter_groups
PolicyAccountLinkFilterGroups = policy_account_link_filter_groups.PolicyAccountLinkFilterGroups
from okta.models import policy_network_condition as policy_network_condition
PolicyNetworkCondition = policy_network_condition.PolicyNetworkCondition
from okta.models import policy_people_condition as policy_people_condition
PolicyPeopleCondition = policy_people_condition.PolicyPeopleCondition
from okta.models import policy_rule as policy_rule
PolicyRule = policy_rule.PolicyRule
from okta.models import policy_rule_auth_context_condition as policy_rule_auth_context_condition
PolicyRuleAuthContextCondition = policy_rule_auth_context_condition.PolicyRuleAuthContextCondition
from okta.models import policy_rule_conditions as policy_rule_conditions
PolicyRuleConditions = policy_rule_conditions.PolicyRuleConditions
from okta.models import policy_subject as policy_subject
PolicySubject = policy_subject.PolicySubject
from okta.models import policy_subject_match_type as policy_subject_match_type
PolicySubjectMatchType = policy_subject_match_type.PolicySubjectMatchType
from okta.models import policy_type as policy_type
PolicyType = policy_type.PolicyType
from okta.models import policy_user_name_template as policy_user_name_template
PolicyUserNameTemplate = policy_user_name_template.PolicyUserNameTemplate
from okta.models import protocol as protocol
Protocol = protocol.Protocol
from okta.models import protocol_algorithm_type as protocol_algorithm_type
ProtocolAlgorithmType = protocol_algorithm_type.ProtocolAlgorithmType
from okta.models import protocol_algorithm_type_signature as protocol_algorithm_type_signature
ProtocolAlgorithmTypeSignature = protocol_algorithm_type_signature.ProtocolAlgorithmTypeSignature
from okta.models import protocol_algorithms as protocol_algorithms
ProtocolAlgorithms = protocol_algorithms.ProtocolAlgorithms
from okta.models import protocol_endpoint as protocol_endpoint
ProtocolEndpoint = protocol_endpoint.ProtocolEndpoint
from okta.models import protocol_endpoints as protocol_endpoints
ProtocolEndpoints = protocol_endpoints.ProtocolEndpoints
from okta.models import protocol_relay_state as protocol_relay_state
ProtocolRelayState = protocol_relay_state.ProtocolRelayState
from okta.models import protocol_relay_state_format as protocol_relay_state_format
ProtocolRelayStateFormat = protocol_relay_state_format.ProtocolRelayStateFormat
from okta.models import protocol_settings as protocol_settings
ProtocolSettings = protocol_settings.ProtocolSettings
from okta.models import provisioning as provisioning
Provisioning = provisioning.Provisioning
from okta.models import provisioning_conditions as provisioning_conditions
ProvisioningConditions = provisioning_conditions.ProvisioningConditions
from okta.models import provisioning_deprovisioned_condition as provisioning_deprovisioned_condition
ProvisioningDeprovisionedCondition = provisioning_deprovisioned_condition.ProvisioningDeprovisionedCondition
from okta.models import provisioning_groups as provisioning_groups
ProvisioningGroups = provisioning_groups.ProvisioningGroups
from okta.models import provisioning_suspended_condition as provisioning_suspended_condition
ProvisioningSuspendedCondition = provisioning_suspended_condition.ProvisioningSuspendedCondition
from okta.models import push_user_factor as push_user_factor
PushUserFactor = push_user_factor.PushUserFactor
from okta.models import push_user_factor_profile as push_user_factor_profile
PushUserFactorProfile = push_user_factor_profile.PushUserFactorProfile
from okta.models import recovery_question_credential as recovery_question_credential
RecoveryQuestionCredential = recovery_question_credential.RecoveryQuestionCredential
from okta.models import reset_password_token as reset_password_token
ResetPasswordToken = reset_password_token.ResetPasswordToken
from okta.models import response_links as response_links
ResponseLinks = response_links.ResponseLinks
from okta.models import risk_policy_rule_condition as risk_policy_rule_condition
RiskPolicyRuleCondition = risk_policy_rule_condition.RiskPolicyRuleCondition
from okta.models import risk_score_policy_rule_condition as risk_score_policy_rule_condition
RiskScorePolicyRuleCondition = risk_score_policy_rule_condition.RiskScorePolicyRuleCondition
from okta.models import role as role
Role = role.Role
from okta.models import role_assignment_type as role_assignment_type
RoleAssignmentType = role_assignment_type.RoleAssignmentType
from okta.models import role_status as role_status
RoleStatus = role_status.RoleStatus
from okta.models import role_type as role_type
RoleType = role_type.RoleType
from okta.models import saml_application as saml_application
SamlApplication = saml_application.SamlApplication
from okta.models import saml_application_settings as saml_application_settings
SamlApplicationSettings = saml_application_settings.SamlApplicationSettings
from okta.models import saml_application_settings_sign_on as saml_application_settings_sign_on
SamlApplicationSettingsSignOn = saml_application_settings_sign_on.SamlApplicationSettingsSignOn
from okta.models import saml_attribute_statement as saml_attribute_statement
SamlAttributeStatement = saml_attribute_statement.SamlAttributeStatement
from okta.models import scheduled_user_lifecycle_action as scheduled_user_lifecycle_action
ScheduledUserLifecycleAction = scheduled_user_lifecycle_action.ScheduledUserLifecycleAction
from okta.models import scheme_application_credentials as scheme_application_credentials
SchemeApplicationCredentials = scheme_application_credentials.SchemeApplicationCredentials
from okta.models import scope as scope
Scope = scope.Scope
from okta.models import scope_type as scope_type
ScopeType = scope_type.ScopeType
from okta.models import secure_password_store_application as secure_password_store_application
SecurePasswordStoreApplication = secure_password_store_application.SecurePasswordStoreApplication
from okta.models import secure_password_store_application_settings as secure_password_store_application_settings
SecurePasswordStoreApplicationSettings = secure_password_store_application_settings.SecurePasswordStoreApplicationSettings
from okta.models import secure_password_store_application_settings_application as secure_password_store_application_settings_application
SecurePasswordStoreApplicationSettingsApplication = secure_password_store_application_settings_application.SecurePasswordStoreApplicationSettingsApplication
from okta.models import security_question as security_question
SecurityQuestion = security_question.SecurityQuestion
from okta.models import security_question_user_factor as security_question_user_factor
SecurityQuestionUserFactor = security_question_user_factor.SecurityQuestionUserFactor
from okta.models import security_question_user_factor_profile as security_question_user_factor_profile
SecurityQuestionUserFactorProfile = security_question_user_factor_profile.SecurityQuestionUserFactorProfile
from okta.models import session as session
Session = session.Session
from okta.models import session_authentication_method as session_authentication_method
SessionAuthenticationMethod = session_authentication_method.SessionAuthenticationMethod
from okta.models import session_identity_provider as session_identity_provider
SessionIdentityProvider = session_identity_provider.SessionIdentityProvider
from okta.models import session_identity_provider_type as session_identity_provider_type
SessionIdentityProviderType = session_identity_provider_type.SessionIdentityProviderType
from okta.models import session_status as session_status
SessionStatus = session_status.SessionStatus
from okta.models import sms_template as sms_template
SmsTemplate = sms_template.SmsTemplate
from okta.models import sms_template_translations as sms_template_translations
SmsTemplateTranslations = sms_template_translations.SmsTemplateTranslations
from okta.models import sms_template_type as sms_template_type
SmsTemplateType = sms_template_type.SmsTemplateType
from okta.models import sms_user_factor as sms_user_factor
SmsUserFactor = sms_user_factor.SmsUserFactor
from okta.models import sms_user_factor_profile as sms_user_factor_profile
SmsUserFactorProfile = sms_user_factor_profile.SmsUserFactorProfile
from okta.models import social_auth_token as social_auth_token
SocialAuthToken = social_auth_token.SocialAuthToken
from okta.models import swa_application as swa_application
SwaApplication = swa_application.SwaApplication
from okta.models import swa_application_settings as swa_application_settings
SwaApplicationSettings = swa_application_settings.SwaApplicationSettings
from okta.models import swa_application_settings_application as swa_application_settings_application
SwaApplicationSettingsApplication = swa_application_settings_application.SwaApplicationSettingsApplication
from okta.models import swa_three_field_application as swa_three_field_application
SwaThreeFieldApplication = swa_three_field_application.SwaThreeFieldApplication
from okta.models import swa_three_field_application_settings as swa_three_field_application_settings
SwaThreeFieldApplicationSettings = swa_three_field_application_settings.SwaThreeFieldApplicationSettings
from okta.models import swa_three_field_application_settings_application as swa_three_field_application_settings_application
SwaThreeFieldApplicationSettingsApplication = swa_three_field_application_settings_application.SwaThreeFieldApplicationSettingsApplication
from okta.models import temp_password as temp_password
TempPassword = temp_password.TempPassword
from okta.models import token_user_factor as token_user_factor
TokenUserFactor = token_user_factor.TokenUserFactor
from okta.models import token_user_factor_profile as token_user_factor_profile
TokenUserFactorProfile = token_user_factor_profile.TokenUserFactorProfile
from okta.models import totp_user_factor as totp_user_factor
TotpUserFactor = totp_user_factor.TotpUserFactor
from okta.models import totp_user_factor_profile as totp_user_factor_profile
TotpUserFactorProfile = totp_user_factor_profile.TotpUserFactorProfile
from okta.models import trusted_origin as trusted_origin
TrustedOrigin = trusted_origin.TrustedOrigin
from okta.models import u_2_f_user_factor as u_2_f_user_factor
U2FUserFactor = u_2_f_user_factor.U2FUserFactor
from okta.models import u_2_f_user_factor_profile as u_2_f_user_factor_profile
U2FUserFactorProfile = u_2_f_user_factor_profile.U2FUserFactorProfile
from okta.models import user as user
User = user.User
from okta.models import user_activation_token as user_activation_token
UserActivationToken = user_activation_token.UserActivationToken
from okta.models import user_condition as user_condition
UserCondition = user_condition.UserCondition
from okta.models import user_credentials as user_credentials
UserCredentials = user_credentials.UserCredentials
from okta.models import user_factor as user_factor
UserFactor = user_factor.UserFactor
from okta.models import user_identifier_condition_evaluator_pattern as user_identifier_condition_evaluator_pattern
UserIdentifierConditionEvaluatorPattern = user_identifier_condition_evaluator_pattern.UserIdentifierConditionEvaluatorPattern
from okta.models import user_identifier_policy_rule_condition as user_identifier_policy_rule_condition
UserIdentifierPolicyRuleCondition = user_identifier_policy_rule_condition.UserIdentifierPolicyRuleCondition
from okta.models import user_identity_provider_link_request as user_identity_provider_link_request
UserIdentityProviderLinkRequest = user_identity_provider_link_request.UserIdentityProviderLinkRequest
from okta.models import user_lifecycle_attribute_policy_rule_condition as user_lifecycle_attribute_policy_rule_condition
UserLifecycleAttributePolicyRuleCondition = user_lifecycle_attribute_policy_rule_condition.UserLifecycleAttributePolicyRuleCondition
from okta.models import user_next_login as user_next_login
UserNextLogin = user_next_login.UserNextLogin
from okta.models import user_policy_rule_condition as user_policy_rule_condition
UserPolicyRuleCondition = user_policy_rule_condition.UserPolicyRuleCondition
from okta.models import user_profile as user_profile
UserProfile = user_profile.UserProfile
from okta.models import user_status as user_status
UserStatus = user_status.UserStatus
from okta.models import user_status_policy_rule_condition as user_status_policy_rule_condition
UserStatusPolicyRuleCondition = user_status_policy_rule_condition.UserStatusPolicyRuleCondition
from okta.models import user_type as user_type
UserType = user_type.UserType
from okta.models import verify_factor_request as verify_factor_request
VerifyFactorRequest = verify_factor_request.VerifyFactorRequest
from okta.models import verify_user_factor_response as verify_user_factor_response
VerifyUserFactorResponse = verify_user_factor_response.VerifyUserFactorResponse
from okta.models import web_authn_user_factor as web_authn_user_factor
WebAuthnUserFactor = web_authn_user_factor.WebAuthnUserFactor
from okta.models import web_authn_user_factor_profile as web_authn_user_factor_profile
WebAuthnUserFactorProfile = web_authn_user_factor_profile.WebAuthnUserFactorProfile
from okta.models import web_user_factor as web_user_factor
WebUserFactor = web_user_factor.WebUserFactor
from okta.models import web_user_factor_profile as web_user_factor_profile
WebUserFactorProfile = web_user_factor_profile.WebUserFactorProfile
from okta.models import ws_federation_application as ws_federation_application
WsFederationApplication = ws_federation_application.WsFederationApplication
from okta.models import ws_federation_application_settings as ws_federation_application_settings
WsFederationApplicationSettings = ws_federation_application_settings.WsFederationApplicationSettings
from okta.models import ws_federation_application_settings_application as ws_federation_application_settings_application
WsFederationApplicationSettingsApplication = ws_federation_application_settings_application.WsFederationApplicationSettingsApplication



# flake8: noqa
"""
Copyright 2020 - Present Okta, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

# AUTO-GENERATED! DO NOT EDIT FILE DIRECTLY
# SEE CONTRIBUTOR DOCUMENTATION

from okta.okta_object import OktaObject
from okta.models import app_and_instance_policy_rule_condition\
    as app_and_instance_policy_rule_condition
from okta.models import app_instance_policy_rule_condition\
    as app_instance_policy_rule_condition
from okta.models import policy_rule_auth_context_condition\
    as policy_rule_auth_context_condition
from okta.models import password_policy_authentication_provider_condition\
    as password_policy_authentication_provider_condition
from okta.models import before_scheduled_action_policy_rule_condition\
    as before_scheduled_action_policy_rule_condition
from okta.models import client_policy_condition\
    as client_policy_condition
from okta.models import context_policy_rule_condition\
    as context_policy_rule_condition
from okta.models import device_policy_rule_condition\
    as device_policy_rule_condition
from okta.models import grant_type_policy_rule_condition\
    as grant_type_policy_rule_condition
from okta.models import group_policy_rule_condition\
    as group_policy_rule_condition
from okta.models import identity_provider_policy_rule_condition\
    as identity_provider_policy_rule_condition
from okta.models import mdm_enrollment_policy_rule_condition\
    as mdm_enrollment_policy_rule_condition
from okta.models import policy_network_condition\
    as policy_network_condition
from okta.models import policy_people_condition\
    as policy_people_condition
from okta.models import platform_policy_rule_condition\
    as platform_policy_rule_condition
from okta.models import risk_policy_rule_condition\
    as risk_policy_rule_condition
from okta.models import risk_score_policy_rule_condition\
    as risk_score_policy_rule_condition
from okta.models import o_auth_2_scopes_mediation_policy_rule_condition\
    as o_auth_2_scopes_mediation_policy_rule_condition
from okta.models import user_identifier_policy_rule_condition\
    as user_identifier_policy_rule_condition
from okta.models import user_status_policy_rule_condition\
    as user_status_policy_rule_condition
from okta.models import user_policy_rule_condition\
    as user_policy_rule_condition


class PolicyRuleConditions(
    OktaObject
):
    """
    A class for PolicyRuleConditions objects.
    """

    def __init__(self, config=None):
        super().__init__(config)
        if config:
            if "app" in config:
                if isinstance(config["app"],
                              app_and_instance_policy_rule_condition.AppAndInstancePolicyRuleCondition):
                    self.app = config["app"]
                elif config["app"] is not None:
                    self.app = app_and_instance_policy_rule_condition.AppAndInstancePolicyRuleCondition(
                        config["app"]
                    )
                else:
                    self.app = None
            else:
                self.app = None
            if "apps" in config:
                if isinstance(config["apps"],
                              app_instance_policy_rule_condition.AppInstancePolicyRuleCondition):
                    self.apps = config["apps"]
                elif config["apps"] is not None:
                    self.apps = app_instance_policy_rule_condition.AppInstancePolicyRuleCondition(
                        config["apps"]
                    )
                else:
                    self.apps = None
            else:
                self.apps = None
            if "authContext" in config:
                if isinstance(config["authContext"],
                              policy_rule_auth_context_condition.PolicyRuleAuthContextCondition):
                    self.auth_context = config["authContext"]
                elif config["authContext"] is not None:
                    self.auth_context = policy_rule_auth_context_condition.PolicyRuleAuthContextCondition(
                        config["authContext"]
                    )
                else:
                    self.auth_context = None
            else:
                self.auth_context = None
            if "authProvider" in config:
                if isinstance(config["authProvider"],
                              password_policy_authentication_provider_condition.PasswordPolicyAuthenticationProviderCondition):
                    self.auth_provider = config["authProvider"]
                elif config["authProvider"] is not None:
                    self.auth_provider = password_policy_authentication_provider_condition.PasswordPolicyAuthenticationProviderCondition(
                        config["authProvider"]
                    )
                else:
                    self.auth_provider = None
            else:
                self.auth_provider = None
            if "beforeScheduledAction" in config:
                if isinstance(config["beforeScheduledAction"],
                              before_scheduled_action_policy_rule_condition.BeforeScheduledActionPolicyRuleCondition):
                    self.before_scheduled_action = config["beforeScheduledAction"]
                elif config["beforeScheduledAction"] is not None:
                    self.before_scheduled_action = before_scheduled_action_policy_rule_condition.BeforeScheduledActionPolicyRuleCondition(
                        config["beforeScheduledAction"]
                    )
                else:
                    self.before_scheduled_action = None
            else:
                self.before_scheduled_action = None
            if "clients" in config:
                if isinstance(config["clients"],
                              client_policy_condition.ClientPolicyCondition):
                    self.clients = config["clients"]
                elif config["clients"] is not None:
                    self.clients = client_policy_condition.ClientPolicyCondition(
                        config["clients"]
                    )
                else:
                    self.clients = None
            else:
                self.clients = None
            if "context" in config:
                if isinstance(config["context"],
                              context_policy_rule_condition.ContextPolicyRuleCondition):
                    self.context = config["context"]
                elif config["context"] is not None:
                    self.context = context_policy_rule_condition.ContextPolicyRuleCondition(
                        config["context"]
                    )
                else:
                    self.context = None
            else:
                self.context = None
            if "device" in config:
                if isinstance(config["device"],
                              device_policy_rule_condition.DevicePolicyRuleCondition):
                    self.device = config["device"]
                elif config["device"] is not None:
                    self.device = device_policy_rule_condition.DevicePolicyRuleCondition(
                        config["device"]
                    )
                else:
                    self.device = None
            else:
                self.device = None
            if "grantTypes" in config:
                if isinstance(config["grantTypes"],
                              grant_type_policy_rule_condition.GrantTypePolicyRuleCondition):
                    self.grant_types = config["grantTypes"]
                elif config["grantTypes"] is not None:
                    self.grant_types = grant_type_policy_rule_condition.GrantTypePolicyRuleCondition(
                        config["grantTypes"]
                    )
                else:
                    self.grant_types = None
            else:
                self.grant_types = None
            if "groups" in config:
                if isinstance(config["groups"],
                              group_policy_rule_condition.GroupPolicyRuleCondition):
                    self.groups = config["groups"]
                elif config["groups"] is not None:
                    self.groups = group_policy_rule_condition.GroupPolicyRuleCondition(
                        config["groups"]
                    )
                else:
                    self.groups = None
            else:
                self.groups = None
            if "identityProvider" in config:
                if isinstance(config["identityProvider"],
                              identity_provider_policy_rule_condition.IdentityProviderPolicyRuleCondition):
                    self.identity_provider = config["identityProvider"]
                elif config["identityProvider"] is not None:
                    self.identity_provider = identity_provider_policy_rule_condition.IdentityProviderPolicyRuleCondition(
                        config["identityProvider"]
                    )
                else:
                    self.identity_provider = None
            else:
                self.identity_provider = None
            if "mdmEnrollment" in config:
                if isinstance(config["mdmEnrollment"],
                              mdm_enrollment_policy_rule_condition.MdmEnrollmentPolicyRuleCondition):
                    self.mdm_enrollment = config["mdmEnrollment"]
                elif config["mdmEnrollment"] is not None:
                    self.mdm_enrollment = mdm_enrollment_policy_rule_condition.MdmEnrollmentPolicyRuleCondition(
                        config["mdmEnrollment"]
                    )
                else:
                    self.mdm_enrollment = None
            else:
                self.mdm_enrollment = None
            if "network" in config:
                if isinstance(config["network"],
                              policy_network_condition.PolicyNetworkCondition):
                    self.network = config["network"]
                elif config["network"] is not None:
                    self.network = policy_network_condition.PolicyNetworkCondition(
                        config["network"]
                    )
                else:
                    self.network = None
            else:
                self.network = None
            if "people" in config:
                if isinstance(config["people"],
                              policy_people_condition.PolicyPeopleCondition):
                    self.people = config["people"]
                elif config["people"] is not None:
                    self.people = policy_people_condition.PolicyPeopleCondition(
                        config["people"]
                    )
                else:
                    self.people = None
            else:
                self.people = None
            if "platform" in config:
                if isinstance(config["platform"],
                              platform_policy_rule_condition.PlatformPolicyRuleCondition):
                    self.platform = config["platform"]
                elif config["platform"] is not None:
                    self.platform = platform_policy_rule_condition.PlatformPolicyRuleCondition(
                        config["platform"]
                    )
                else:
                    self.platform = None
            else:
                self.platform = None
            if "risk" in config:
                if isinstance(config["risk"],
                              risk_policy_rule_condition.RiskPolicyRuleCondition):
                    self.risk = config["risk"]
                elif config["risk"] is not None:
                    self.risk = risk_policy_rule_condition.RiskPolicyRuleCondition(
                        config["risk"]
                    )
                else:
                    self.risk = None
            else:
                self.risk = None
            if "riskScore" in config:
                if isinstance(config["riskScore"],
                              risk_score_policy_rule_condition.RiskScorePolicyRuleCondition):
                    self.risk_score = config["riskScore"]
                elif config["riskScore"] is not None:
                    self.risk_score = risk_score_policy_rule_condition.RiskScorePolicyRuleCondition(
                        config["riskScore"]
                    )
                else:
                    self.risk_score = None
            else:
                self.risk_score = None
            if "scopes" in config:
                if isinstance(config["scopes"],
                              o_auth_2_scopes_mediation_policy_rule_condition.OAuth2ScopesMediationPolicyRuleCondition):
                    self.scopes = config["scopes"]
                elif config["scopes"] is not None:
                    self.scopes = o_auth_2_scopes_mediation_policy_rule_condition.OAuth2ScopesMediationPolicyRuleCondition(
                        config["scopes"]
                    )
                else:
                    self.scopes = None
            else:
                self.scopes = None
            if "userIdentifier" in config:
                if isinstance(config["userIdentifier"],
                              user_identifier_policy_rule_condition.UserIdentifierPolicyRuleCondition):
                    self.user_identifier = config["userIdentifier"]
                elif config["userIdentifier"] is not None:
                    self.user_identifier = user_identifier_policy_rule_condition.UserIdentifierPolicyRuleCondition(
                        config["userIdentifier"]
                    )
                else:
                    self.user_identifier = None
            else:
                self.user_identifier = None
            if "userStatus" in config:
                if isinstance(config["userStatus"],
                              user_status_policy_rule_condition.UserStatusPolicyRuleCondition):
                    self.user_status = config["userStatus"]
                elif config["userStatus"] is not None:
                    self.user_status = user_status_policy_rule_condition.UserStatusPolicyRuleCondition(
                        config["userStatus"]
                    )
                else:
                    self.user_status = None
            else:
                self.user_status = None
            if "users" in config:
                if isinstance(config["users"],
                              user_policy_rule_condition.UserPolicyRuleCondition):
                    self.users = config["users"]
                elif config["users"] is not None:
                    self.users = user_policy_rule_condition.UserPolicyRuleCondition(
                        config["users"]
                    )
                else:
                    self.users = None
            else:
                self.users = None
        else:
            self.app = None
            self.apps = None
            self.auth_context = None
            self.auth_provider = None
            self.before_scheduled_action = None
            self.clients = None
            self.context = None
            self.device = None
            self.grant_types = None
            self.groups = None
            self.identity_provider = None
            self.mdm_enrollment = None
            self.network = None
            self.people = None
            self.platform = None
            self.risk = None
            self.risk_score = None
            self.scopes = None
            self.user_identifier = None
            self.user_status = None
            self.users = None

    def request_format(self):
        parent_req_format = super().request_format()
        current_obj_format = {
            "app": self.app,
            "apps": self.apps,
            "authContext": self.auth_context,
            "authProvider": self.auth_provider,
            "beforeScheduledAction": self.before_scheduled_action,
            "clients": self.clients,
            "context": self.context,
            "device": self.device,
            "grantTypes": self.grant_types,
            "groups": self.groups,
            "identityProvider": self.identity_provider,
            "mdmEnrollment": self.mdm_enrollment,
            "network": self.network,
            "people": self.people,
            "platform": self.platform,
            "risk": self.risk,
            "riskScore": self.risk_score,
            "scopes": self.scopes,
            "userIdentifier": self.user_identifier,
            "userStatus": self.user_status,
            "users": self.users
        }
        parent_req_format.update(current_obj_format)
        return parent_req_format
